aboutsummaryrefslogtreecommitdiff
path: root/src/database/sql/driver/driver.go
diff options
context:
space:
mode:
Diffstat (limited to 'src/database/sql/driver/driver.go')
-rw-r--r--src/database/sql/driver/driver.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/database/sql/driver/driver.go b/src/database/sql/driver/driver.go
index 6113af79c5..6bea8f9de9 100644
--- a/src/database/sql/driver/driver.go
+++ b/src/database/sql/driver/driver.go
@@ -222,9 +222,9 @@ type ConnBeginTx interface {
BeginTx(ctx context.Context, opts TxOptions) (Tx, error)
}
// ResetSessioner may be implemented by Conn to allow drivers to reset the
// session state associated with the connection and to signal a bad connection.
-type ResetSessioner interface {
+type SessionResetter interface {
// ResetSession is called while a connection is in the connection
// pool. No queries will run on this connection until this method returns.
//
@@ -222,9 +222,9 @@ type ConnBeginTx interface {
BeginTx(ctx context.Context, opts TxOptions) (Tx, error)
}
-// ResetSessioner may be implemented by Conn to allow drivers to reset the
+// SessionResetter may be implemented by Conn to allow drivers to reset the
// session state associated with the connection and to signal a bad connection.